"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[5662],{94721:function(t,e,i){var r=i(63366),n=i(87462),a=i(72791),o=i(28182),l=i(94419),c=i(12065),d=i(66934),h=i(31402),v=i(90133),s=i(80184),f=["absolute","children","className","component","flexItem","light","orientation","role","textAlign","variant"],u=(0,d.ZP)("div",{name:"MuiDivider",slot:"Root",overridesResolver:function(t,e){var i=t.ownerState;return[e.root,i.absolute&&e.absolute,e[i.variant],i.light&&e.light,"vertical"===i.orientation&&e.vertical,i.flexItem&&e.flexItem,i.children&&e.withChildren,i.children&&"vertical"===i.orientation&&e.withChildrenVertical,"right"===i.textAlign&&"vertical"!==i.orientation&&e.textAlignRight,"left"===i.textAlign&&"vertical"!==i.orientation&&e.textAlignLeft]}})((function(t){var e=t.theme,i=t.ownerState;return(0,n.Z)({margin:0,flexShrink:0,borderWidth:0,borderStyle:"solid",borderColor:(e.vars||e).palette.divider,borderBottomWidth:"thin"},i.absolute&&{position:"absolute",bottom:0,left:0,width:"100%"},i.light&&{borderColor:e.vars?"rgba(".concat(e.vars.palette.dividerChannel," / 0.08)"):(0,c.Fq)(e.palette.divider,.08)},"inset"===i.variant&&{marginLeft:72},"middle"===i.variant&&"horizontal"===i.orientation&&{marginLeft:e.spacing(2),marginRight:e.spacing(2)},"middle"===i.variant&&"vertical"===i.orientation&&{marginTop:e.spacing(1),marginBottom:e.spacing(1)},"vertical"===i.orientation&&{height:"100%",borderBottomWidth:0,borderRightWidth:"thin"},i.flexItem&&{alignSelf:"stretch",height:"auto"})}),(function(t){var e=t.theme,i=t.ownerState;return(0,n.Z)({},i.children&&{display:"flex",whiteSpace:"nowrap",textAlign:"center",border:0,"&::before, &::after":{position:"relative",width:"100%",borderTop:"thin solid ".concat((e.vars||e).palette.divider),top:"50%",content:'""',transform:"translateY(50%)"}})}),(function(t){var e=t.theme,i=t.ownerState;return(0,n.Z)({},i.children&&"vertical"===i.orientation&&{flexDirection:"column","&::before, &::after":{height:"100%",top:"0%",left:"50%",borderTop:0,borderLeft:"thin solid ".concat((e.vars||e).palette.divider),transform:"translateX(0%)"}})}),(function(t){var e=t.ownerState;return(0,n.Z)({},"right"===e.textAlign&&"vertical"!==e.orientation&&{"&::before":{width:"90%"},"&::after":{width:"10%"}},"left"===e.textAlign&&"vertical"!==e.orientation&&{"&::before":{width:"10%"},"&::after":{width:"90%"}})})),g=(0,d.ZP)("span",{name:"MuiDivider",slot:"Wrapper",overridesResolver:function(t,e){var i=t.ownerState;return[e.wrapper,"vertical"===i.orientation&&e.wrapperVertical]}})((function(t){var e=t.theme,i=t.ownerState;return(0,n.Z)({display:"inline-block",paddingLeft:"calc(".concat(e.spacing(1)," * 1.2)"),paddingRight:"calc(".concat(e.spacing(1)," * 1.2)")},"vertical"===i.orientation&&{paddingTop:"calc(".concat(e.spacing(1)," * 1.2)"),paddingBottom:"calc(".concat(e.spacing(1)," * 1.2)")})})),p=a.forwardRef((function(t,e){var i=(0,h.Z)({props:t,name:"MuiDivider"}),a=i.absolute,c=void 0!==a&&a,d=i.children,p=i.className,m=i.component,w=void 0===m?d?"div":"hr":m,b=i.flexItem,x=void 0!==b&&b,Z=i.light,A=void 0!==Z&&Z,C=i.orientation,S=void 0===C?"horizontal":C,R=i.role,I=void 0===R?"hr"!==w?"separator":void 0:R,V=i.textAlign,D=void 0===V?"center":V,L=i.variant,W=void 0===L?"fullWidth":L,k=(0,r.Z)(i,f),M=(0,n.Z)({},i,{absolute:c,component:w,flexItem:x,light:A,orientation:S,role:I,textAlign:D,variant:W}),y=function(t){var e=t.absolute,i=t.children,r=t.classes,n=t.flexItem,a=t.light,o=t.orientation,c=t.textAlign,d={root:["root",e&&"absolute",t.variant,a&&"light","vertical"===o&&"vertical",n&&"flexItem",i&&"withChildren",i&&"vertical"===o&&"withChildrenVertical","right"===c&&"vertical"!==o&&"textAlignRight","left"===c&&"vertical"!==o&&"textAlignLeft"],wrapper:["wrapper","vertical"===o&&"wrapperVertical"]};return(0,l.Z)(d,v.V,r)}(M);return(0,s.jsx)(u,(0,n.Z)({as:w,className:(0,o.Z)(y.root,p),role:I,ref:e,ownerState:M},k,{children:d?(0,s.jsx)(g,{className:y.wrapper,ownerState:M,children:d}):null}))}));e.Z=p},90133:function(t,e,i){i.d(e,{V:function(){return a}});var r=i(75878),n=i(21217);function a(t){return(0,n.Z)("MuiDivider",t)}var o=(0,r.Z)("MuiDivider",["root","absolute","fullWidth","inset","middle","flexItem","light","vertical","withChildren","withChildrenVertical","textAlignRight","textAlignLeft","wrapper","wrapperVertical"]);e.Z=o},45662:function(t,e,i){i.r(e),i.d(e,{default:function(){return r.Z},dividerClasses:function(){return n.Z},getDividerUtilityClass:function(){return n.V}});var r=i(94721),n=i(90133)}}]);
//# sourceMappingURL=5662.9183ecf4.chunk.js.map