"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[2632],{19795:function(t,e,o){var r=o(63366),i=o(87462),n=o(72791),s=o(28182),a=o(94419),c=o(66934),l=o(31402),u=o(14036),d=o(12540),f=o(80184),p=["className","color","component","disableGutters","disableSticky","inset"],b=(0,c.ZP)("li",{name:"MuiListSubheader",slot:"Root",overridesResolver:function(t,e){var o=t.ownerState;return[e.root,"default"!==o.color&&e["color".concat((0,u.Z)(o.color))],!o.disableGutters&&e.gutters,o.inset&&e.inset,!o.disableSticky&&e.sticky]}})((function(t){var e=t.theme,o=t.ownerState;return(0,i.Z)({boxSizing:"border-box",lineHeight:"48px",listStyle:"none",color:(e.vars||e).palette.text.secondary,fontFamily:e.typography.fontFamily,fontWeight:e.typography.fontWeightMedium,fontSize:e.typography.pxToRem(14)},"primary"===o.color&&{color:(e.vars||e).palette.primary.main},"inherit"===o.color&&{color:"inherit"},!o.disableGutters&&{paddingLeft:16,paddingRight:16},o.inset&&{paddingLeft:72},!o.disableSticky&&{position:"sticky",top:0,zIndex:1,backgroundColor:(e.vars||e).palette.background.paper})})),y=n.forwardRef((function(t,e){var o=(0,l.Z)({props:t,name:"MuiListSubheader"}),n=o.className,c=o.color,y=void 0===c?"default":c,h=o.component,m=void 0===h?"li":h,v=o.disableGutters,S=void 0!==v&&v,g=o.disableSticky,k=void 0!==g&&g,Z=o.inset,x=void 0!==Z&&Z,L=(0,r.Z)(o,p),w=(0,i.Z)({},o,{color:y,component:m,disableGutters:S,disableSticky:k,inset:x}),G=function(t){var e=t.classes,o=t.color,r=t.disableGutters,i=t.inset,n=t.disableSticky,s={root:["root","default"!==o&&"color".concat((0,u.Z)(o)),!r&&"gutters",i&&"inset",!n&&"sticky"]};return(0,a.Z)(s,d.s,e)}(w);return(0,f.jsx)(b,(0,i.Z)({as:m,className:(0,s.Z)(G.root,n),ref:e,ownerState:w},L))}));e.Z=y},12632:function(t,e,o){o.r(e),o.d(e,{default:function(){return r.Z},getListSubheaderUtilityClass:function(){return i.s},listSubheaderClasses:function(){return i.Z}});var r=o(19795),i=o(12540)},12540:function(t,e,o){o.d(e,{s:function(){return n}});var r=o(75878),i=o(21217);function n(t){return(0,i.Z)("MuiListSubheader",t)}var s=(0,r.Z)("MuiListSubheader",["root","colorPrimary","colorInherit","gutters","inset","sticky"]);e.Z=s}}]);
//# sourceMappingURL=2632.1e8a1222.chunk.js.map