"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[3619],{63619:function(u,e,n){n.r(e),n.d(e,{default:function(){return t.Z},getMenuUtilityClass:function(){return s.Q},menuClasses:function(){return s.Z}});var t=n(52744),s=n(35782)}}]);