"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[9910,5071],{4567:function(r,a,t){var n=t(63366),o=t(87462),i=t(72791),e=t(28182),p=t(78519),h=t(94419),g=t(66934),u=t(31402),l=t(14036),s=t(40940),c=t(80184),m=["align","className","component","gutterBottom","noWrap","paragraph","variant","variantMapping"],v=(0,g.ZP)("span",{name:"MuiTypography",slot:"Root",overridesResolver:function(r,a){var t=r.ownerState;return[a.root,t.variant&&a[t.variant],"inherit"!==t.align&&a["align".concat((0,l.Z)(t.align))],t.noWrap&&a.noWrap,t.gutterBottom&&a.gutterBottom,t.paragraph&&a.paragraph]}})((function(r){var a=r.theme,t=r.ownerState;return(0,o.Z)({margin:0},t.variant&&a.typography[t.variant],"inherit"!==t.align&&{textAlign:t.align},t.noWrap&&{overflow:"hidden",textOverflow:"ellipsis",whiteSpace:"nowrap"},t.gutterBottom&&{marginBottom:"0.35em"},t.paragraph&&{marginBottom:16})})),y={h1:"h1",h2:"h2",h3:"h3",h4:"h4",h5:"h5",h6:"h6",subtitle1:"h6",subtitle2:"h6",body1:"p",body2:"p",inherit:"p"},f={primary:"primary.main",textPrimary:"text.primary",secondary:"secondary.main",textSecondary:"text.secondary",error:"error.main"},d=i.forwardRef((function(r,a){var t=(0,u.Z)({props:r,name:"MuiTypography"}),i=function(r){return f[r]||r}(t.color),g=(0,p.Z)((0,o.Z)({},t,{color:i})),d=g.align,Z=void 0===d?"inherit":d,b=g.className,B=g.component,w=g.gutterBottom,W=void 0!==w&&w,x=g.noWrap,M=void 0!==x&&x,C=g.paragraph,S=void 0!==C&&C,T=g.variant,k=void 0===T?"body1":T,N=g.variantMapping,R=void 0===N?y:N,P=(0,n.Z)(g,m),_=(0,o.Z)({},g,{align:Z,color:i,className:b,component:B,gutterBottom:W,noWrap:M,paragraph:S,variant:k,variantMapping:R}),j=B||(S?"p":R[k]||y[k])||"span",A=function(r){var a=r.align,t=r.gutterBottom,n=r.noWrap,o=r.paragraph,i=r.variant,e=r.classes,p={root:["root",i,"inherit"!==r.align&&"align".concat((0,l.Z)(a)),t&&"gutterBottom",n&&"noWrap",o&&"paragraph"]};return(0,h.Z)(p,s.f,e)}(_);return(0,c.jsx)(v,(0,o.Z)({as:j,ref:a,ownerState:_,className:(0,e.Z)(A.root,b)},P))}));a.Z=d},49910:function(r,a,t){t.r(a),t.d(a,{default:function(){return n.Z},getTypographyUtilityClass:function(){return o.f},typographyClasses:function(){return o.Z}});var n=t(4567),o=t(40940)},40940:function(r,a,t){t.d(a,{f:function(){return i}});var n=t(75878),o=t(21217);function i(r){return(0,o.Z)("MuiTypography",r)}var e=(0,n.Z)("MuiTypography",["root","h1","h2","h3","h4","h5","h6","subtitle1","subtitle2","body1","body2","inherit","button","caption","overline","alignLeft","alignRight","alignCenter","alignJustify","noWrap","gutterBottom","paragraph"]);a.Z=e}}]);
//# sourceMappingURL=9910.2822939e.chunk.js.map