"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[2812],{12812:function(n,a,e){e.r(a),e.d(a,{default:function(){return m},dialogActionsClasses:function(){return g},getDialogActionsUtilityClass:function(){return d}});var i=e(63366),t=e(87462),o=e(72791),s=e(28182),r=e(94419),c=e(66934),l=e(31402),u=e(75878),f=e(21217);function d(n){return(0,f.Z)("MuiDialogActions",n)}var g=(0,u.Z)("MuiDialogActions",["root","spacing"]),p=e(80184),v=["className","disableSpacing"],Z=(0,c.ZP)("div",{name:"MuiDialogActions",slot:"Root",overridesResolver:function(n,a){var e=n.ownerState;return[a.root,!e.disableSpacing&&a.spacing]}})((function(n){var a=n.ownerState;return(0,t.Z)({display:"flex",alignItems:"center",padding:8,justifyContent:"flex-end",flex:"0 0 auto"},!a.disableSpacing&&{"& > :not(:first-of-type)":{marginLeft:8}})})),m=o.forwardRef((function(n,a){var e=(0,l.Z)({props:n,name:"MuiDialogActions"}),o=e.className,c=e.disableSpacing,u=void 0!==c&&c,f=(0,i.Z)(e,v),g=(0,t.Z)({},e,{disableSpacing:u}),m=function(n){var a=n.classes,e={root:["root",!n.disableSpacing&&"spacing"]};return(0,r.Z)(e,d,a)}(g);return(0,p.jsx)(Z,(0,t.Z)({className:(0,s.Z)(m.root,o),ownerState:g,ref:a},f))}))}}]);
//# sourceMappingURL=2812.0748017b.chunk.js.map