"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[1580],{1580:function(e,n,r){r.r(n),r.d(n,{default:function(){return a}});r(72791);var u=r(29886),c=r(83361),s=r(80184),t=(0,c.Z)({key:"css",prepend:!0});function a(e){var n=e.injectFirst,r=e.children;return n?(0,s.jsx)(u.C,{value:t,children:r}):r}}}]);
//# sourceMappingURL=1580.cb98f4ac.chunk.js.map