"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[4526],{34526:function(e,n,u){u.r(n),u.d(n,{default:function(){return i}});var t=u(1413),r=u(72791),s=u(80184),c=r.lazy((function(){return u.e(9056).then(u.bind(u,89056))}));function i(e){return(0,s.jsx)(r.Suspense,{children:(0,s.jsx)(c,(0,t.Z)((0,t.Z)({type:"submit"},e),{},{children:e.children||"submit"}),"submit")})}}}]);
//# sourceMappingURL=4526.2830e6be.chunk.js.map