"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[2805],{32805:function(n,e,r){r.r(e),r.d(e,{default:function(){return h}});var t=r(1413),c=r(45987),u=r(72791),s=r(58121),a=r.n(s),f=r(80184),i=["context","children"],o=u.lazy((function(){return r.e(8286).then(r.bind(r,68286))}));function h(n){var e=n.context,r=(n.children,(0,c.Z)(n,i));return(0,f.jsx)(u.Suspense,{children:(0,f.jsx)(o,(0,t.Z)({},Object.assign(a()(e.props.formData||{}),r)))})}}}]);
//# sourceMappingURL=2805.a15dcdde.chunk.js.map