"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[5634],{5634:function(n,e,r){r.r(e),r.d(e,{default:function(){return p}});var t=r(1413),i=r(72791),u=r(25984),o=r(80184),a=i.lazy((function(){return Promise.all([r.e(2770),r.e(4171)]).then(r.bind(r,74171))})),c=i.lazy((function(){return r.e(3436).then(r.bind(r,3436))})),s=i.lazy((function(){return r.e(9910).then(r.bind(r,49910))})),l=i.lazy((function(){return r.e(3372).then(r.bind(r,23372))})),d=i.lazy((function(){return r.e(3517).then(r.bind(r,3517))})),h=i.lazy((function(){return r.e(1131).then(r.bind(r,81131))}));function p(n){var e=n.elements||{},r=(0,u.x0)();return(0,o.jsx)(i.Suspense,{children:(0,o.jsx)(d,(0,t.Z)((0,t.Z)({spacing:1},n),{},{children:n.children.map((function(n,i){return(0,o.jsxs)(a,(0,t.Z)((0,t.Z)({TransitionProps:{unmountOnExit:!0}},(e[i]||{}).props),{},{children:[(0,o.jsx)(c,(0,t.Z)((0,t.Z)({sx:{backgroundColor:"lightgray"},expandIcon:(0,o.jsx)(h,{}),"aria-controls":r+i+"-content",id:r+i+"-header"},(e[i]||{}).propsSummary),{},{children:(0,o.jsx)(s,{children:(e[i]||{}).name||((n.props||{}).schema||{}).title||(n.props||{}).name})})),(0,o.jsx)(l,(0,t.Z)((0,t.Z)({id:r+i+"-details"},(e[i]||{}).propsDetails),{},{children:n}))]}),i)}))}))})}},25984:function(n,e,r){r.d(e,{x0:function(){return t}});var t=function(){var n=arguments.length>0&&void 0!==arguments[0]?arguments[0]:21;return crypto.getRandomValues(new Uint8Array(n)).reduce((function(n,e){return n+=(e&=63)<36?e.toString(36):e<62?(e-26).toString(36).toUpperCase():e>62?"-":"_"}),"")}}}]);
//# sourceMappingURL=5634.998e186d.chunk.js.map