"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[6769],{49484:function(e,n,t){var r=t(72791),u=t(47563),c=t(58956),o=t(99723),i=t(80184);function f(e){return e.substring(2).toLowerCase()}n.Z=function(e){var n=e.children,t=e.disableReactTree,s=void 0!==t&&t,a=e.mouseEvent,v=void 0===a?"onClick":a,d=e.onClickAway,l=e.touchEvent,m=void 0===l?"onTouchEnd":l,E=r.useRef(!1),h=r.useRef(null),p=r.useRef(!1),L=r.useRef(!1);r.useEffect((function(){return setTimeout((function(){p.current=!0}),0),function(){p.current=!1}}),[]);var Z=(0,u.Z)(n.ref,h),k=(0,c.Z)((function(e){var n=L.current;L.current=!1;var t=(0,o.Z)(h.current);!p.current||!h.current||"clientX"in e&&function(e,n){return n.documentElement.clientWidth<e.clientX||n.documentElement.clientHeight<e.clientY}(e,t)||(E.current?E.current=!1:(e.composedPath?e.composedPath().indexOf(h.current)>-1:!t.documentElement.contains(e.target)||h.current.contains(e.target))||!s&&n||d(e))})),g=function(e){return function(t){L.current=!0;var r=n.props[e];r&&r(t)}},C={ref:Z};return!1!==m&&(C[m]=g(m)),r.useEffect((function(){if(!1!==m){var e=f(m),n=(0,o.Z)(h.current),t=function(){E.current=!0};return n.addEventListener(e,k),n.addEventListener("touchmove",t),function(){n.removeEventListener(e,k),n.removeEventListener("touchmove",t)}}}),[k,m]),!1!==v&&(C[v]=g(v)),r.useEffect((function(){if(!1!==v){var e=f(v),n=(0,o.Z)(h.current);return n.addEventListener(e,k),function(){n.removeEventListener(e,k)}}}),[k,v]),(0,i.jsx)(r.Fragment,{children:r.cloneElement(n,C)})}},16769:function(e,n,t){t.r(n),t.d(n,{default:function(){return r.Z}});var r=t(49484)}}]);
//# sourceMappingURL=6769.4d10d57b.chunk.js.map