"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[2503],{13208:function(n,t,e){var i=e(87462),r=e(63366),o=e(72791),a=e(26752),u=e(13967),s=e(4999),c=e(42071),d=e(80184),f=["addEndListener","appear","children","easing","in","onEnter","onEntered","onEntering","onExit","onExited","onExiting","style","timeout","TransitionComponent"];function l(n){return"scale(".concat(n,", ").concat(Math.pow(n,2),")")}var g={entering:{opacity:1,transform:l(1)},entered:{opacity:1,transform:"none"}},y="undefined"!==typeof navigator&&/^((?!chrome|android).)*(safari|mobile)/i.test(navigator.userAgent)&&/(os |version\/)15(.|_)4/i.test(navigator.userAgent),m=o.forwardRef((function(n,t){var e=n.addEndListener,m=n.appear,p=void 0===m||m,E=n.children,v=n.easing,h=n.in,x=n.onEnter,Z=n.onEntered,C=n.onEntering,A=n.onExit,R=n.onExited,b=n.onExiting,k=n.style,w=n.timeout,H=void 0===w?"auto":w,T=n.TransitionComponent,j=void 0===T?a.ZP:T,L=(0,r.Z)(n,f),_=o.useRef(),D=o.useRef(),M=(0,u.Z)(),P=o.useRef(null),S=(0,c.Z)(P,E.ref,t),q=function(n){return function(t){if(n){var e=P.current;void 0===t?n(e):n(e,t)}}},z=q(C),B=q((function(n,t){(0,s.n)(n);var e,i=(0,s.C)({style:k,timeout:H,easing:v},{mode:"enter"}),r=i.duration,o=i.delay,a=i.easing;"auto"===H?(e=M.transitions.getAutoHeightDuration(n.clientHeight),D.current=e):e=r,n.style.transition=[M.transitions.create("opacity",{duration:e,delay:o}),M.transitions.create("transform",{duration:y?e:.666*e,delay:o,easing:a})].join(","),x&&x(n,t)})),F=q(Z),G=q(b),I=q((function(n){var t,e=(0,s.C)({style:k,timeout:H,easing:v},{mode:"exit"}),i=e.duration,r=e.delay,o=e.easing;"auto"===H?(t=M.transitions.getAutoHeightDuration(n.clientHeight),D.current=t):t=i,n.style.transition=[M.transitions.create("opacity",{duration:t,delay:r}),M.transitions.create("transform",{duration:y?t:.666*t,delay:y?r:r||.333*t,easing:o})].join(","),n.style.opacity=0,n.style.transform=l(.75),A&&A(n)})),J=q(R);return o.useEffect((function(){return function(){clearTimeout(_.current)}}),[]),(0,d.jsx)(j,(0,i.Z)({appear:p,in:h,nodeRef:P,onEnter:B,onEntered:F,onEntering:z,onExit:I,onExited:J,onExiting:G,addEndListener:function(n){"auto"===H&&(_.current=setTimeout(n,D.current||0)),e&&e(P.current,n)},timeout:"auto"===H?null:H},L,{children:function(n,t){return o.cloneElement(E,(0,i.Z)({style:(0,i.Z)({opacity:0,transform:l(.75),visibility:"exited"!==n||h?void 0:"hidden"},g[n],k,E.props.style),ref:S},t))}}))}));m.muiSupportAuto=!0,t.Z=m},22503:function(n,t,e){e.r(t),e.d(t,{default:function(){return i.Z}});var i=e(13208)},13967:function(n,t,e){e.d(t,{Z:function(){return o}});e(72791);var i=e(30418),r=e(36482);function o(){return(0,i.Z)(r.Z)}}}]);
//# sourceMappingURL=2503.d2c7755a.chunk.js.map