"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[633],{21707:function(e,n,u){var t=u(64836);Object.defineProperty(n,"__esModule",{value:!0}),n.default=n.FullScreenComponent=void 0;var r=u(72791),o=t(u(52007)),f=t(u(90752)),l=function(e){var n=e.children,u=e.onChange,t=e.onError,o=(0,r.useRef)();return(0,r.useEffect)((function(){f.default.onchange((function(){u&&u()})),f.default.on("error",(function(){t&&t()}))}),[]),n({ref:o,isEnabled:f.default.isEnabled,onToggle:function(){f.default.toggle(o.current)},onRequest:function(){f.default.request(o.current)},onExit:function(){f.default.exit(o.current)}})};n.FullScreenComponent=l,l.propTypes={children:o.default.func,onChange:o.default.func,onError:o.default.func};var a=(0,r.memo)(l);n.default=a},90633:function(e,n,u){var t=u(64836);Object.defineProperty(n,"__esModule",{value:!0}),Object.defineProperty(n,"default",{enumerable:!0,get:function(){return r.default}});var r=t(u(21707))}}]);
//# sourceMappingURL=633.d8f9a7c0.chunk.js.map