"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[6260],{56260:function(n,o,i){i.r(o),i.d(o,{accordionActionsClasses:function(){return p},default:function(){return Z},getAccordionActionsUtilityClass:function(){return f}});var e=i(63366),t=i(87462),r=i(72791),a=i(28182),c=i(94419),s=i(66934),u=i(31402),d=i(75878),l=i(21217);function f(n){return(0,l.Z)("MuiAccordionActions",n)}var p=(0,d.Z)("MuiAccordionActions",["root","spacing"]),g=i(80184),A=["className","disableSpacing"],v=(0,s.ZP)("div",{name:"MuiAccordionActions",slot:"Root",overridesResolver:function(n,o){var i=n.ownerState;return[o.root,!i.disableSpacing&&o.spacing]}})((function(n){var o=n.ownerState;return(0,t.Z)({display:"flex",alignItems:"center",padding:8,justifyContent:"flex-end"},!o.disableSpacing&&{"& > :not(:first-of-type)":{marginLeft:8}})})),Z=r.forwardRef((function(n,o){var i=(0,u.Z)({props:n,name:"MuiAccordionActions"}),r=i.className,s=i.disableSpacing,d=void 0!==s&&s,l=(0,e.Z)(i,A),p=(0,t.Z)({},i,{disableSpacing:d}),Z=function(n){var o=n.classes,i={root:["root",!n.disableSpacing&&"spacing"]};return(0,c.Z)(i,f,o)}(p);return(0,g.jsx)(v,(0,t.Z)({className:(0,a.Z)(Z.root,r),ref:o,ownerState:p},l))}))}}]);
//# sourceMappingURL=6260.2de8ffad.chunk.js.map