"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[1009],{31009:function(e,u,a){var f=a(64836);Object.defineProperty(u,"__esModule",{value:!0}),u.default=void 0;var l=f(a(45649)),t=a(80184),d=(0,l.default)((0,t.jsx)("path",{d:"M15.41 7.41 14 6l-6 6 6 6 1.41-1.41L10.83 12z"}),"ChevronLeft");u.default=d}}]);
//# sourceMappingURL=1009.029f5412.chunk.js.map