"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[2504],{64554:function(e,a,r){r.d(a,{Z:function(){return Z}});var n=r(87462),t=r(63366),o=r(72791),s=r(28182),u=r(53842),f=r(60104),l=r(78519),c=r(30418),d=r(80184),i=["className","component"];var m=r(55902),h=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},a=e.defaultTheme,r=e.defaultClassName,m=void 0===r?"MuiBox-root":r,h=e.generateClassName,Z=(0,u.ZP)("div",{shouldForwardProp:function(e){return"theme"!==e&&"sx"!==e&&"as"!==e}})(f.Z),v=o.forwardRef((function(e,r){var o=(0,c.Z)(a),u=(0,l.Z)(e),f=u.className,v=u.component,N=void 0===v?"div":v,p=(0,t.Z)(u,i);return(0,d.jsx)(Z,(0,n.Z)({as:N,ref:r,className:(0,s.Z)(f,h?h(m):m),theme:o},p))}));return v}({defaultTheme:(0,r(61979).Z)(),defaultClassName:"MuiBox-root",generateClassName:m.Z.generate}),Z=h},82504:function(e,a,r){r.r(a),r.d(a,{default:function(){return n.Z}});var n=r(64554)}}]);
//# sourceMappingURL=2504.566faeb8.chunk.js.map