"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[2347],{42347:function(n,a,r){r.r(a),r.d(a,{cardActionsClasses:function(){return p},default:function(){return m},getCardActionsUtilityClass:function(){return f}});var e=r(63366),t=r(87462),i=r(72791),s=r(28182),o=r(94419),c=r(66934),u=r(31402),d=r(75878),l=r(21217);function f(n){return(0,l.Z)("MuiCardActions",n)}var p=(0,d.Z)("MuiCardActions",["root","spacing"]),g=r(80184),v=["disableSpacing","className"],Z=(0,c.ZP)("div",{name:"MuiCardActions",slot:"Root",overridesResolver:function(n,a){var r=n.ownerState;return[a.root,!r.disableSpacing&&a.spacing]}})((function(n){var a=n.ownerState;return(0,t.Z)({display:"flex",alignItems:"center",padding:8},!a.disableSpacing&&{"& > :not(:first-of-type)":{marginLeft:8}})})),m=i.forwardRef((function(n,a){var r=(0,u.Z)({props:n,name:"MuiCardActions"}),i=r.disableSpacing,c=void 0!==i&&i,d=r.className,l=(0,e.Z)(r,v),p=(0,t.Z)({},r,{disableSpacing:c}),m=function(n){var a=n.classes,r={root:["root",!n.disableSpacing&&"spacing"]};return(0,o.Z)(r,f,a)}(p);return(0,g.jsx)(Z,(0,t.Z)({className:(0,s.Z)(m.root,d),ownerState:p,ref:a},l))}))}}]);
//# sourceMappingURL=2347.b57c2795.chunk.js.map