"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[7020],{96174:function(n,e,t){var r=t(29439),u=t(72791),l=t(54164),c=t(47563),f=t(75721),i=t(62971),o=t(80184);var a=u.forwardRef((function(n,e){var t=n.children,a=n.container,d=n.disablePortal,s=void 0!==d&&d,Z=u.useState(null),h=(0,r.Z)(Z,2),m=h[0],v=h[1],b=(0,c.Z)(u.isValidElement(t)?t.ref:null,e);return(0,f.Z)((function(){s||v(function(n){return"function"===typeof n?n():n}(a)||document.body)}),[a,s]),(0,f.Z)((function(){if(m&&!s)return(0,i.Z)(e,m),function(){(0,i.Z)(e,null)}}),[e,m,s]),s?u.isValidElement(t)?u.cloneElement(t,{ref:b}):t:(0,o.jsx)(u.Fragment,{children:m?l.createPortal(t,m):m})}));e.Z=a},77020:function(n,e,t){t.r(e),t.d(e,{default:function(){return r.Z}});var r=t(96174)}}]);
//# sourceMappingURL=7020.cbd8083e.chunk.js.map