"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[9410],{76090:function(t,n,e){var i=e(4942),r=e(63366),o=e(87462),a=e(72791),s=e(28182),u=e(26752),c=e(94419),l=e(66934),d=e(31402),p=e(81314),f=e(4999),h=e(13967),v=e(42071),m=e(98751),Z=e(80184),g=["addEndListener","children","className","collapsedSize","component","easing","in","onEnter","onEntered","onEntering","onExit","onExited","onExiting","orientation","style","timeout","TransitionComponent"],w=(0,l.ZP)("div",{name:"MuiCollapse",slot:"Root",overridesResolver:function(t,n){var e=t.ownerState;return[n.root,n[e.orientation],"entered"===e.state&&n.entered,"exited"===e.state&&!e.in&&"0px"===e.collapsedSize&&n.hidden]}})((function(t){var n=t.theme,e=t.ownerState;return(0,o.Z)({height:0,overflow:"hidden",transition:n.transitions.create("height")},"horizontal"===e.orientation&&{height:"auto",width:0,transition:n.transitions.create("width")},"entered"===e.state&&(0,o.Z)({height:"auto",overflow:"visible"},"horizontal"===e.orientation&&{width:"auto"}),"exited"===e.state&&!e.in&&"0px"===e.collapsedSize&&{visibility:"hidden"})})),x=(0,l.ZP)("div",{name:"MuiCollapse",slot:"Wrapper",overridesResolver:function(t,n){return n.wrapper}})((function(t){var n=t.ownerState;return(0,o.Z)({display:"flex",width:"100%"},"horizontal"===n.orientation&&{width:"auto",height:"100%"})})),y=(0,l.ZP)("div",{name:"MuiCollapse",slot:"WrapperInner",overridesResolver:function(t,n){return n.wrapperInner}})((function(t){var n=t.ownerState;return(0,o.Z)({width:"100%"},"horizontal"===n.orientation&&{width:"auto",height:"100%"})})),E=a.forwardRef((function(t,n){var e=(0,d.Z)({props:t,name:"MuiCollapse"}),l=e.addEndListener,E=e.children,C=e.className,S=e.collapsedSize,z=void 0===S?"0px":S,R=e.component,b=e.easing,D=e.in,I=e.onEnter,M=e.onEntered,T=e.onEntering,N=e.onExit,j=e.onExited,k=e.onExiting,H=e.orientation,P=void 0===H?"vertical":H,W=e.style,A=e.timeout,L=void 0===A?p.x9.standard:A,F=e.TransitionComponent,_=void 0===F?u.ZP:F,U=(0,r.Z)(e,g),q=(0,o.Z)({},e,{orientation:P,collapsedSize:z}),B=function(t){var n=t.orientation,e=t.classes,i={root:["root","".concat(n)],entered:["entered"],hidden:["hidden"],wrapper:["wrapper","".concat(n)],wrapperInner:["wrapperInner","".concat(n)]};return(0,c.Z)(i,m.d,e)}(q),G=(0,h.Z)(),J=a.useRef(),K=a.useRef(null),O=a.useRef(),Q="number"===typeof z?"".concat(z,"px"):z,V="horizontal"===P,X=V?"width":"height";a.useEffect((function(){return function(){clearTimeout(J.current)}}),[]);var Y=a.useRef(null),$=(0,v.Z)(n,Y),tt=function(t){return function(n){if(t){var e=Y.current;void 0===n?t(e):t(e,n)}}},nt=function(){return K.current?K.current[V?"clientWidth":"clientHeight"]:0},et=tt((function(t,n){K.current&&V&&(K.current.style.position="absolute"),t.style[X]=Q,I&&I(t,n)})),it=tt((function(t,n){var e=nt();K.current&&V&&(K.current.style.position="");var i=(0,f.C)({style:W,timeout:L,easing:b},{mode:"enter"}),r=i.duration,o=i.easing;if("auto"===L){var a=G.transitions.getAutoHeightDuration(e);t.style.transitionDuration="".concat(a,"ms"),O.current=a}else t.style.transitionDuration="string"===typeof r?r:"".concat(r,"ms");t.style[X]="".concat(e,"px"),t.style.transitionTimingFunction=o,T&&T(t,n)})),rt=tt((function(t,n){t.style[X]="auto",M&&M(t,n)})),ot=tt((function(t){t.style[X]="".concat(nt(),"px"),N&&N(t)})),at=tt(j),st=tt((function(t){var n=nt(),e=(0,f.C)({style:W,timeout:L,easing:b},{mode:"exit"}),i=e.duration,r=e.easing;if("auto"===L){var o=G.transitions.getAutoHeightDuration(n);t.style.transitionDuration="".concat(o,"ms"),O.current=o}else t.style.transitionDuration="string"===typeof i?i:"".concat(i,"ms");t.style[X]=Q,t.style.transitionTimingFunction=r,k&&k(t)}));return(0,Z.jsx)(_,(0,o.Z)({in:D,onEnter:et,onEntered:rt,onEntering:it,onExit:ot,onExited:at,onExiting:st,addEndListener:function(t){"auto"===L&&(J.current=setTimeout(t,O.current||0)),l&&l(Y.current,t)},nodeRef:Y,timeout:"auto"===L?null:L},U,{children:function(t,n){return(0,Z.jsx)(w,(0,o.Z)({as:R,className:(0,s.Z)(B.root,C,{entered:B.entered,exited:!D&&"0px"===Q&&B.hidden}[t]),style:(0,o.Z)((0,i.Z)({},V?"minWidth":"minHeight",Q),W),ownerState:(0,o.Z)({},q,{state:t}),ref:$},n,{children:(0,Z.jsx)(x,{ownerState:(0,o.Z)({},q,{state:t}),className:B.wrapper,ref:K,children:(0,Z.jsx)(y,{ownerState:(0,o.Z)({},q,{state:t}),className:B.wrapperInner,children:E})})}))}}))}));E.muiSupportAuto=!0,n.Z=E},98751:function(t,n,e){e.d(n,{d:function(){return o}});var i=e(75878),r=e(21217);function o(t){return(0,r.Z)("MuiCollapse",t)}var a=(0,i.Z)("MuiCollapse",["root","horizontal","vertical","entered","hidden","wrapper","wrapperInner"]);n.Z=a},49410:function(t,n,e){e.r(n),e.d(n,{collapseClasses:function(){return r.Z},default:function(){return i.Z},getCollapseUtilityClass:function(){return r.d}});var i=e(76090),r=e(98751)},13967:function(t,n,e){e.d(n,{Z:function(){return o}});e(72791);var i=e(30418),r=e(36482);function o(){return(0,i.Z)(r.Z)}}}]);
//# sourceMappingURL=9410.cb7643af.chunk.js.map