"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[4950],{11393:function(t,e,r){var n=r(72791).createContext({});e.Z=n},94950:function(t,e,r){r.r(e),r.d(e,{default:function(){return Z},getImageListUtilityClass:function(){return v},imageListClasses:function(){return f}});var n=r(63366),a=r(87462),o=r(94419),i=r(28182),s=r(72791),u=r(66934),l=r(31402),c=r(75878),d=r(21217);function v(t){return(0,d.Z)("MuiImageList",t)}var f=(0,c.Z)("MuiImageList",["root","masonry","quilted","standard","woven"]),m=r(11393),g=r(80184),p=["children","className","cols","component","rowHeight","gap","style","variant"],h=(0,u.ZP)("ul",{name:"MuiImageList",slot:"Root",overridesResolver:function(t,e){var r=t.ownerState;return[e.root,e[r.variant]]}})((function(t){var e=t.ownerState;return(0,a.Z)({display:"grid",overflowY:"auto",listStyle:"none",padding:0,WebkitOverflowScrolling:"touch"},"masonry"===e.variant&&{display:"block"})})),Z=s.forwardRef((function(t,e){var r=(0,l.Z)({props:t,name:"MuiImageList"}),u=r.children,c=r.className,d=r.cols,f=void 0===d?2:d,Z=r.component,w=void 0===Z?"ul":Z,y=r.rowHeight,C=void 0===y?"auto":y,k=r.gap,L=void 0===k?4:k,I=r.style,M=r.variant,S=void 0===M?"standard":M,b=(0,n.Z)(r,p),H=s.useMemo((function(){return{rowHeight:C,gap:L,variant:S}}),[C,L,S]);s.useEffect((function(){0}),[]);var x="masonry"===S?(0,a.Z)({columnCount:f,columnGap:L},I):(0,a.Z)({gridTemplateColumns:"repeat(".concat(f,", 1fr)"),gap:L},I),N=(0,a.Z)({},r,{component:w,gap:L,rowHeight:C,variant:S}),R=function(t){var e=t.classes,r={root:["root",t.variant]};return(0,o.Z)(r,v,e)}(N);return(0,g.jsx)(h,(0,a.Z)({as:w,className:(0,i.Z)(R.root,R[S],c),ref:e,style:x,ownerState:N},b,{children:(0,g.jsx)(m.Z.Provider,{value:H,children:u})}))}))}}]);
//# sourceMappingURL=4950.6eb865b7.chunk.js.map