"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[9075],{33671:function(n,t,e){e.d(t,{Z:function(){return M}});var a=e(30168),i=e(63366),r=e(87462),o=e(72791),s=e(28182),h=e(52554),u=e(94419);function l(n){return String(n).match(/[\d.\-+]*\s*(.*)/)[1]||""}function d(n){return parseFloat(n)}var c,f,m,v,p,g,w,b,k=e(12065),C=e(66934),Z=e(31402),y=e(88813),S=e(80184),R=["animation","className","component","height","style","variant","width"],x=(0,h.F4)(p||(p=c||(c=(0,a.Z)(["\n  0% {\n    opacity: 1;\n  }\n\n  50% {\n    opacity: 0.4;\n  }\n\n  100% {\n    opacity: 1;\n  }\n"])))),B=(0,h.F4)(g||(g=f||(f=(0,a.Z)(["\n  0% {\n    transform: translateX(-100%);\n  }\n\n  50% {\n    /* +0.5s of delay between each loop */\n    transform: translateX(100%);\n  }\n\n  100% {\n    transform: translateX(100%);\n  }\n"])))),F=(0,C.ZP)("span",{name:"MuiSkeleton",slot:"Root",overridesResolver:function(n,t){var e=n.ownerState;return[t.root,t[e.variant],!1!==e.animation&&t[e.animation],e.hasChildren&&t.withChildren,e.hasChildren&&!e.width&&t.fitContent,e.hasChildren&&!e.height&&t.heightAuto]}})((function(n){var t=n.theme,e=n.ownerState,a=l(t.shape.borderRadius)||"px",i=d(t.shape.borderRadius);return(0,r.Z)({display:"block",backgroundColor:t.vars?t.vars.palette.Skeleton.bg:(0,k.Fq)(t.palette.text.primary,"light"===t.palette.mode?.11:.13),height:"1.2em"},"text"===e.variant&&{marginTop:0,marginBottom:0,height:"auto",transformOrigin:"0 55%",transform:"scale(1, 0.60)",borderRadius:"".concat(i).concat(a,"/").concat(Math.round(i/.6*10)/10).concat(a),"&:empty:before":{content:'"\\00a0"'}},"circular"===e.variant&&{borderRadius:"50%"},"rounded"===e.variant&&{borderRadius:(t.vars||t).shape.borderRadius},e.hasChildren&&{"& > *":{visibility:"hidden"}},e.hasChildren&&!e.width&&{maxWidth:"fit-content"},e.hasChildren&&!e.height&&{height:"auto"})}),(function(n){return"pulse"===n.ownerState.animation&&(0,h.iv)(w||(w=m||(m=(0,a.Z)(["\n      animation: "," 1.5s ease-in-out 0.5s infinite;\n    "]))),x)}),(function(n){var t=n.ownerState,e=n.theme;return"wave"===t.animation&&(0,h.iv)(b||(b=v||(v=(0,a.Z)(["\n      position: relative;\n      overflow: hidden;\n\n      /* Fix bug in Safari https://bugs.webkit.org/show_bug.cgi?id=68196 */\n      -webkit-mask-image: -webkit-radial-gradient(white, black);\n\n      &::after {\n        animation: "," 1.6s linear 0.5s infinite;\n        background: linear-gradient(\n          90deg,\n          transparent,\n          ",",\n          transparent\n        );\n        content: '';\n        position: absolute;\n        transform: translateX(-100%); /* Avoid flash during server-side hydration */\n        bottom: 0;\n        left: 0;\n        right: 0;\n        top: 0;\n      }\n    "]))),B,(e.vars||e).palette.action.hover)})),M=o.forwardRef((function(n,t){var e=(0,Z.Z)({props:n,name:"MuiSkeleton"}),a=e.animation,o=void 0===a?"pulse":a,h=e.className,l=e.component,d=void 0===l?"span":l,c=e.height,f=e.style,m=e.variant,v=void 0===m?"text":m,p=e.width,g=(0,i.Z)(e,R),w=(0,r.Z)({},e,{animation:o,component:d,variant:v,hasChildren:Boolean(g.children)}),b=function(n){var t=n.classes,e=n.variant,a=n.animation,i=n.hasChildren,r=n.width,o=n.height,s={root:["root",e,a,i&&"withChildren",i&&!r&&"fitContent",i&&!o&&"heightAuto"]};return(0,u.Z)(s,y.B,t)}(w);return(0,S.jsx)(F,(0,r.Z)({as:d,ref:t,className:(0,s.Z)(b.root,h),ownerState:w},g,{style:(0,r.Z)({width:p,height:c},f)}))}))},39075:function(n,t,e){e.r(t),e.d(t,{default:function(){return a.Z},getSkeletonUtilityClass:function(){return i.B},skeletonClasses:function(){return i.Z}});var a=e(33671),i=e(88813)},88813:function(n,t,e){e.d(t,{B:function(){return r}});var a=e(75878),i=e(21217);function r(n){return(0,i.Z)("MuiSkeleton",n)}var o=(0,a.Z)("MuiSkeleton",["root","text","rectangular","rounded","circular","pulse","wave","withChildren","fitContent","heightAuto"]);t.Z=o}}]);
//# sourceMappingURL=9075.4416bdb4.chunk.js.map